/*
#ident	"@(#)smail/src:RELEASE-3_2_0_115:lookup.h,v 1.10 2003/04/21 21:56:30 woods Exp"
 */

/*
 *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
 *    Copyright (C) 1992  Ronald S. Karr
 * 
 * See the file COPYING, distributed with smail, for restriction
 * and warranty information.
 */

/*
 * lookup.:
 *	Interface file for lookup.c
 */

/* macros used in communicating with functions in lookup.c */
#define DB_FAIL		(-1)		/* unrecoverable failure */
#define DB_AGAIN	(-2)		/* retry operation at a later time */
#define DB_NOMATCH	(-3)		/* no match was found */
#define DB_SUCCEED	0		/* operation was successful */
#define FILE_SUCCEED	0		/* operation on file was successful */
#define FILE_FAIL	(-4)		/* unrecoverable database failure */
#define FILE_AGAIN	(-5)		/* try using database later */
#define FILE_NOMATCH	(-6)		/* no such file */

/* WARNING: bindlib.c defines DB_NEGMATCH as (-8) */

/* external functions defined in lookup.c */
extern int open_database __P((char *, char *, int, unsigned int, struct stat *, char **, char **));
extern void close_database __P((char *));
extern int lookup_database __P((char *, char *, char **, char **));
extern int match_re __P((char *, char *, unsigned int, char **, char **, char **, char **));
extern int match_re_list __P((char *, char *, unsigned int, char **));
extern int match_hostname __P((char *, char *, char **));
extern int match_ip __P((char *, char *, int, int, int, char **));
extern int match_ip_net __P((char *, char *, int));
extern char *flip_inet_addr __P((char *));
